@@ -46,9 +46,7 @@ struct _EggSMClientPrivate
 	GKeyFile *state_file;
 };
 
-#define EGG_SM_CLIENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), EGG_TYPE_SM_CLIENT, EggSMClientPrivate))
-
-G_DEFINE_TYPE (EggSMClient, egg_sm_client, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE (EggSMClient, egg_sm_client, G_TYPE_OBJECT)
 
 static EggSMClient *global_client;
 static EggSMClientMode global_client_mode = EGG_SM_CLIENT_MODE_NORMAL;
@@ -64,8 +62,6 @@ egg_sm_client_class_init (EggSMClientClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (klass, sizeof (EggSMClientPrivate));
-
 	/**
 	 * EggSMClient::save_state:
 	 * @client: the client
@@ -333,23 +329,7 @@ egg_sm_client_get (void)
 		if (global_client_mode != EGG_SM_CLIENT_MODE_DISABLED &&
 		        !sm_client_disable)
 		{
-#if defined (GDK_WINDOWING_WIN32)
-			global_client = egg_sm_client_win32_new ();
-#elif defined (GDK_WINDOWING_QUARTZ)
-			global_client = egg_sm_client_osx_new ();
-#else
-			/* If both D-Bus and XSMP are compiled in, try XSMP first
-			 * (since it supports state saving) and fall back to D-Bus
-			 * if XSMP isn't available.
-			 */
-# ifdef EGG_SM_CLIENT_BACKEND_XSMP
 			global_client = egg_sm_client_xsmp_new ();
-# endif
-# ifdef EGG_SM_CLIENT_BACKEND_DBUS
-			if (!global_client)
-				global_client = egg_sm_client_dbus_new ();
-# endif
-#endif
 		}
 
 		/* Fallback: create a dummy client, so that callers don't have
@@ -403,7 +383,7 @@ egg_sm_client_is_resumed (EggSMClient *client)
 GKeyFile *
 egg_sm_client_get_state_file (EggSMClient *client)
 {
-	EggSMClientPrivate *priv = EGG_SM_CLIENT_GET_PRIVATE (client);
+	EggSMClientPrivate *priv = egg_sm_client_get_instance_private (client);
 	char *state_file_path;
 	GError *err = NULL;
 
