@@ -174,6 +174,9 @@ static GRegex **url_regexes;
 static TerminalURLFlavour *url_regex_flavors;
 static guint n_url_regexes;
 
+static void terminal_screen_url_match_remove (TerminalScreen *screen);
+
+
 #ifdef ENABLE_SKEY
 static const TerminalRegexPattern skey_regex_patterns[] =
 {
@@ -187,7 +190,7 @@ static guint n_skey_regexes;
 static void  terminal_screen_skey_match_remove (TerminalScreen            *screen);
 #endif /* ENABLE_SKEY */
 
-G_DEFINE_TYPE (TerminalScreen, terminal_screen, VTE_TYPE_TERMINAL)
+G_DEFINE_TYPE_WITH_PRIVATE (TerminalScreen, terminal_screen, VTE_TYPE_TERMINAL)
 
 static char *
 cwd_of_pid (int pid)
@@ -333,14 +336,12 @@ terminal_screen_init (TerminalScreen *screen)
 		{ "text/x-moz-url",  0, TARGET_MOZ_URL },
 		{ "_NETSCAPE_URL", 0, TARGET_NETSCAPE_URL }
 	};
-	VteTerminal *terminal = VTE_TERMINAL (screen);
 	TerminalScreenPrivate *priv;
 	GtkTargetList *target_list;
 	GtkTargetEntry *targets;
 	int n_targets;
-	guint i;
 
-	priv = screen->priv = G_TYPE_INSTANCE_GET_PRIVATE (screen, TERMINAL_TYPE_SCREEN, TerminalScreenPrivate);
+	priv = screen->priv = terminal_screen_get_instance_private (screen);
 
 	vte_terminal_set_mouse_autohide (VTE_TERMINAL (screen), TRUE);
 #if VTE_CHECK_VERSION (0, 52, 0)
@@ -351,18 +352,6 @@ terminal_screen_init (TerminalScreen *screen)
 
 	priv->font_scale = PANGO_SCALE_MEDIUM;
 
-	for (i = 0; i < n_url_regexes; ++i)
-	{
-		TagData *tag_data;
-
-		tag_data = g_slice_new (TagData);
-		tag_data->flavor = url_regex_flavors[i];
-		tag_data->tag = vte_terminal_match_add_gregex (terminal, url_regexes[i], 0);
-		vte_terminal_match_set_cursor_type (terminal, tag_data->tag, URL_MATCH_CURSOR);
-
-		priv->match_tags = g_slist_prepend (priv->match_tags, tag_data);
-	}
-
 	/* Setup DND */
 	target_list = gtk_target_list_new (NULL, 0);
 	gtk_target_list_add_uri_targets (target_list, 0);
@@ -579,8 +568,6 @@ terminal_screen_class_init (TerminalScreenClass *klass)
 	                     G_TYPE_STRV,
 	                     G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
-	g_type_class_add_private (object_class, sizeof (TerminalScreenPrivate));
-
 	/* Precompile the regexes */
 	n_url_regexes = G_N_ELEMENTS (url_regex_patterns);
 	url_regexes = g_new0 (GRegex*, n_url_regexes);
@@ -1060,6 +1047,29 @@ terminal_screen_profile_notify_cb (TerminalProfile *profile,
 		vte_terminal_set_cursor_shape (vte_terminal,
 		                               terminal_profile_get_property_enum (priv->profile, TERMINAL_PROFILE_CURSOR_SHAPE));
 
+	if (!prop_name || prop_name == I_(TERMINAL_PROFILE_USE_URLS))
+	{
+		if (terminal_profile_get_property_boolean (profile, TERMINAL_PROFILE_USE_URLS))
+		{
+			guint i;
+
+			for (i = 0; i < n_url_regexes; ++i)
+			{
+				TagData *tag_data;
+
+				tag_data = g_slice_new (TagData);
+				tag_data->flavor = url_regex_flavors[i];
+				tag_data->tag = vte_terminal_match_add_gregex (vte_terminal, url_regexes[i], 0);
+				vte_terminal_match_set_cursor_type (vte_terminal, tag_data->tag, URL_MATCH_CURSOR);
+
+				priv->match_tags = g_slist_prepend (priv->match_tags, tag_data);
+			}
+		}
+		else
+		{
+			terminal_screen_url_match_remove (screen);
+		}
+	}
 	g_object_thaw_notify (object);
 }
 
@@ -1939,13 +1949,17 @@ terminal_screen_child_exited (VteTerminal *terminal, int status)
 	switch (action)
 	{
 	case TERMINAL_EXIT_CLOSE:
-		g_signal_emit (screen, signals[CLOSE_SCREEN], 0);
+		if ((status != 9) || (priv->override_command != NULL))
+			g_signal_emit (screen, signals[CLOSE_SCREEN], 0);
 		break;
 	case TERMINAL_EXIT_RESTART:
 		terminal_screen_launch_child_on_idle (screen);
 		break;
 	case TERMINAL_EXIT_HOLD:
 	{
+		if ((status == 9) && (priv->override_command == NULL))
+			break;
+
 		GtkWidget *info_bar;
 
 		info_bar = terminal_info_bar_new (GTK_MESSAGE_INFO,
@@ -2312,6 +2326,30 @@ terminal_screen_skey_match_remove (TerminalScreen *screen)
 }
 #endif /* ENABLE_SKEY */
 
+static void
+terminal_screen_url_match_remove (TerminalScreen *screen)
+{
+	TerminalScreenPrivate *priv = screen->priv;
+	GSList *l, *next;
+
+	l = priv->match_tags;
+	while (l != NULL)
+	{
+		TagData *tag_data = (TagData *) l->data;
+
+		next = l->next;
+#ifdef ENABLE_SKEY
+		if (tag_data->flavor != FLAVOR_SKEY)
+#endif
+		{
+			vte_terminal_match_remove (VTE_TERMINAL (screen), tag_data->tag);
+			priv->match_tags = g_slist_delete_link (priv->match_tags, l);
+		}
+
+		l = next;
+	}
+}
+
 static char*
 terminal_screen_check_match (TerminalScreen *screen,
                              GdkEvent  *event,
