@@ -25,8 +25,6 @@
 #include "terminal-tab-label.h"
 #include "terminal-close-button.h"
 
-#define TERMINAL_TAB_LABEL_GET_PRIVATE(tab_label)(G_TYPE_INSTANCE_GET_PRIVATE ((tab_label), TERMINAL_TYPE_TAB_LABEL, TerminalTabLabelPrivate))
-
 #define SPACING (4)
 
 struct _TerminalTabLabelPrivate
@@ -51,7 +49,7 @@ enum
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE (TerminalTabLabel, terminal_tab_label, GTK_TYPE_BOX);
+G_DEFINE_TYPE_WITH_PRIVATE (TerminalTabLabel, terminal_tab_label, GTK_TYPE_BOX);
 
 /* helper functions */
 
@@ -95,7 +93,7 @@ terminal_tab_label_parent_set (GtkWidget *widget,
 static void
 terminal_tab_label_init (TerminalTabLabel *tab_label)
 {
-	tab_label->priv = TERMINAL_TAB_LABEL_GET_PRIVATE (tab_label);
+	tab_label->priv = terminal_tab_label_get_instance_private (tab_label);
 }
 
 static GObject *
@@ -121,13 +119,8 @@ terminal_tab_label_constructor (GType type,
 
 	priv->label = label = gtk_label_new (NULL);
 
-#if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
 	gtk_label_set_yalign (GTK_LABEL (label), 0.5);
-#else
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_misc_set_padding (GTK_MISC (label), 0, 0);
-#endif
 	gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
 	gtk_label_set_single_line_mode (GTK_LABEL (label), TRUE);
 
@@ -150,6 +143,23 @@ terminal_tab_label_constructor (GType type,
 	return object;
 }
 
+static void
+terminal_tab_label_dispose (GObject *object)
+{
+	TerminalTabLabel *tab_label = TERMINAL_TAB_LABEL (object);
+	TerminalTabLabelPrivate *priv = tab_label->priv;
+
+	if (priv->screen != NULL) {
+		g_signal_handlers_disconnect_by_func (priv->screen,
+		                                      G_CALLBACK (sync_tab_label),
+		                                      priv->label);
+		g_object_unref (priv->screen);
+		priv->screen = NULL;
+	}
+
+	G_OBJECT_CLASS (terminal_tab_label_parent_class)->dispose (object);
+}
+
 static void
 terminal_tab_label_finalize (GObject *object)
 {
@@ -170,7 +180,7 @@ terminal_tab_label_set_property (GObject *object,
 	switch (prop_id)
 	{
 	case PROP_SCREEN:
-		priv->screen = g_value_get_object (value);
+		priv->screen = g_value_dup_object (value);
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -185,6 +195,7 @@ terminal_tab_label_class_init (TerminalTabLabelClass *klass)
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
 	gobject_class->constructor = terminal_tab_label_constructor;
+	gobject_class->dispose = terminal_tab_label_dispose;
 	gobject_class->finalize = terminal_tab_label_finalize;
 	gobject_class->set_property = terminal_tab_label_set_property;
 
@@ -207,8 +218,6 @@ terminal_tab_label_class_init (TerminalTabLabelClass *klass)
 	                      TERMINAL_TYPE_SCREEN,
 	                      G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 	                      G_PARAM_CONSTRUCT_ONLY));
-
-	g_type_class_add_private (gobject_class, sizeof (TerminalTabLabelPrivate));
 }
 
 /* public API */
